"use client";

import { useState } from "react";
import { useRouter } from "next/navigation";
import { useAuth } from "@/lib/hooks/useAuth";
import { useClasses } from "@/lib/hooks/useClasses";
import { useTeachers } from "@/lib/hooks/useTeachers";
import DashboardLayout from "@/components/layout/DashboardLayout";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import {
  Dialog,
  DialogContent,
  DialogDescription,
  DialogHeader,
  DialogTitle,
} from "@/components/ui/dialog";
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from "@/components/ui/table";
import {
  Card,
  CardContent,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { toast } from "sonner";
import { BookOpen, Plus, Search } from "lucide-react";
import { Class, Student } from "@/lib/types";
import { useStudents } from "@/lib/hooks/useStudents";


export default function ClassesPage() {
  const router = useRouter();
  const { user, loading: authLoading } = useAuth();
  const { classes, addClass, updateClass, loading: classesLoading } = useClasses();
  const { teachers, loading: teachersLoading } = useTeachers();
  const { students } = useStudents();

  const [isAddDialogOpen, setIsAddDialogOpen] = useState(false);
  const [isEditDialogOpen, setIsEditDialogOpen] = useState(false);
  const [searchQuery, setSearchQuery] = useState("");
  const [selectedClass, setSelectedClass] = useState<Class | null>(null);
  const [newClass, setNewClass] = useState({
    name: "",
    level: "",
    description: "",
    teacherId: "",
  });

  const getStudentCountForClass = (classId: string): number => {
    return students.filter((student: Student) => 
      student.classIds?.includes(classId)
    ).length;
  };

  const handleAddClass = async () => {
    try {
      await addClass({
        ...newClass,
        createdAt: new Date().toISOString(),
      });
      setIsAddDialogOpen(false);
      toast.success("Class added successfully", {
        style: {
          background: '#4BB543', // Green color for success
          color: '#ffffff',
          border: '1px solid #3FAF3A',
        },
      });
      setNewClass({ name: "", level: "", description: "", teacherId: "" });
    } catch (error) {
      toast.error("Failed to add class", {
        style: {
          background: '#FF3333', // Red color for error
          color: '#ffffff',
          border: '1px solid #E60000',
        },
      });
    }
  };

  const handleEditClass = async () => {
    if (!selectedClass) return;

    try {
      await updateClass(selectedClass.id, {
        name: selectedClass.name,
        level: selectedClass.level,
        description: selectedClass.description,
        teacherId: selectedClass.teacherId,
      });
      setIsEditDialogOpen(false);
      toast.success("Class updated successfully", {
        style: {
          background: '#4BB543', // Green color for success
          color: '#ffffff',
          border: '1px solid #3FAF3A',
        },
      });
    } catch (error) {
      toast.error("Failed to update class", {
        style: {
          background: '#FF3333', // Red color for error
          color: '#ffffff',
          border: '1px solid #E60000',
        },
      });
    }
  };

  const handleEdit = (cls: Class) => {
    setSelectedClass(cls);
    setIsEditDialogOpen(true);
  };

  const filteredClasses = classes.filter(cls =>
    cls.name.toLowerCase().includes(searchQuery.toLowerCase()) ||
    cls.level!.toLowerCase().includes(searchQuery.toLowerCase())
  );

  const activeTeachers = teachers.filter(teacher => teacher.status === "active");

  if (authLoading || classesLoading || teachersLoading) {
    return (
      <DashboardLayout>
        <div className="flex items-center justify-center h-[calc(100vh-4rem)]">
          <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
        </div>
      </DashboardLayout>
    );
  }

  return (
    <DashboardLayout>
      <div className="space-y-6">
        <div className="flex justify-between items-center">
          <div>
            <h1 className="text-3xl font-bold tracking-tight">Classes</h1>
            <p className="text-muted-foreground">
              View and manage class information
            </p>
          </div>
          {user?.role === "admin" && (
            <Button onClick={() => setIsAddDialogOpen(true)}>
              <Plus className="h-4 w-4 mr-2" />
              Add Class
            </Button>
          )}
        </div>

        <Card>
          <CardHeader>
            <div className="flex items-center justify-between">
              <CardTitle>All Classes</CardTitle>
              <div className="relative w-64">
                <Search className="absolute left-2.5 top-2.5 h-4 w-4 text-muted-foreground" />
                <Input
                  placeholder="Search classes..."
                  className="pl-8"
                  value={searchQuery}
                  onChange={(e) => setSearchQuery(e.target.value)}
                />
              </div>
            </div>
          </CardHeader>
          <CardContent>
            <Table>
              <TableHeader>
                <TableRow>
                  <TableHead>Class Name</TableHead>
                  <TableHead>Level</TableHead>
                  <TableHead>Teacher</TableHead>
                  <TableHead>Number of Students</TableHead>
                  <TableHead>Actions</TableHead>
                </TableRow>
              </TableHeader>
              <TableBody>
                {filteredClasses.length === 0 ? (
                  <TableRow>
                    <TableCell colSpan={5} className="text-center py-8">
                      No classes found
                    </TableCell>
                  </TableRow>
                ) : (
                  filteredClasses.map((cls) => (
                    <TableRow key={cls.id}>
                      <TableCell className="font-medium">{cls.name}</TableCell>
                      <TableCell>{cls.level}</TableCell>
                      <TableCell>{cls.teacherName || "Unassigned"}</TableCell>
                      <TableCell>{getStudentCountForClass(cls.id)}</TableCell>
                      <TableCell className="space-x-2">
                        <Button
                          variant="ghost"
                          size="sm"
                          onClick={() => router.push(`/students?classId=${cls.id}`)}
                        >
                          View Students
                        </Button>
                        {user?.role === "admin" && (
                          <Button
                            variant="outline"
                            size="sm"
                            onClick={() => handleEdit(cls)}
                          >
                            Edit
                          </Button>
                        )}
                      </TableCell>
                    </TableRow>
                  ))
                )}
              </TableBody>
            </Table>
          </CardContent>
        </Card>

        {/* Add Class Dialog */}
        <Dialog open={isAddDialogOpen} onOpenChange={setIsAddDialogOpen}>
          <DialogContent>
            <DialogHeader>
              <DialogTitle>Add New Class</DialogTitle>
              <DialogDescription>
                Create a new class in the system
              </DialogDescription>
            </DialogHeader>
            <div className="space-y-4 py-4">
              <div className="space-y-2">
                <label className="text-sm font-medium">Class Name</label>
                <Input
                  value={newClass.name}
                  onChange={(e) => setNewClass({ ...newClass, name: e.target.value })}
                />
              </div>
              <div className="space-y-2">
                <label className="text-sm font-medium">Level</label>
                <Input
                  value={newClass.level}
                  onChange={(e) => setNewClass({ ...newClass, level: e.target.value })}
                />
              </div>
              <div className="space-y-2">
                <label className="text-sm font-medium">Description</label>
                <Input
                  value={newClass.description}
                  onChange={(e) => setNewClass({ ...newClass, description: e.target.value })}
                />
              </div>
              <div className="space-y-2">
                <label className="text-sm font-medium">Assign Teacher</label>
                <Select
                  value={newClass.teacherId}
                  onValueChange={(value) => setNewClass({ ...newClass, teacherId: value === "unassigned" ? "" : value })}
                >
                  <SelectTrigger>
                    <SelectValue placeholder="Select a teacher" />
                  </SelectTrigger>
                  <SelectContent>
                    <SelectItem value="unassigned">Unassigned</SelectItem>
                    {activeTeachers.map((teacher) => (
                      <SelectItem key={teacher.id} value={teacher.id}>
                        {teacher.firstName} {teacher.lastName}
                      </SelectItem>
                    ))}
                  </SelectContent>
                </Select>
              </div>
              <div className="flex justify-end space-x-2">
                <Button variant="outline" onClick={() => setIsAddDialogOpen(false)}>
                  Cancel
                </Button>
                <Button onClick={handleAddClass}>
                  Add Class
                </Button>
              </div>
            </div>
          </DialogContent>
        </Dialog>

        {/* Edit Class Dialog */}
        <Dialog open={isEditDialogOpen} onOpenChange={setIsEditDialogOpen}>
          <DialogContent>
            <DialogHeader>
              <DialogTitle>Edit Class</DialogTitle>
              <DialogDescription>
                Update class information
              </DialogDescription>
            </DialogHeader>
            <div className="space-y-4 py-4">
              <div className="space-y-2">
                <label className="text-sm font-medium">Class Name</label>
                <Input
                  value={selectedClass?.name || ""}
                  onChange={(e) => setSelectedClass(selectedClass ? { 
                    ...selectedClass, 
                    name: e.target.value 
                  } : null)}
                />
              </div>
              <div className="space-y-2">
                <label className="text-sm font-medium">Level</label>
                <Input
                  value={selectedClass?.level || ""}
                  onChange={(e) => setSelectedClass(selectedClass ? { 
                    ...selectedClass, 
                    level: e.target.value 
                  } : null)}
                />
              </div>
              <div className="space-y-2">
                <label className="text-sm font-medium">Description</label>
                <Input
                  value={selectedClass?.description || ""}
                  onChange={(e) => setSelectedClass(selectedClass ? { 
                    ...selectedClass, 
                    description: e.target.value 
                  } : null)}
                />
              </div>
              <div className="space-y-2">
                <label className="text-sm font-medium">Assign Teacher</label>
                <Select
                  value={selectedClass?.teacherId || "unassigned"}
                  onValueChange={(value) => setSelectedClass(selectedClass ? { 
                    ...selectedClass, 
                    teacherId: value === "unassigned" ? "" : value 
                  } : null)}
                >
                  <SelectTrigger>
                    <SelectValue placeholder="Select a teacher" />
                  </SelectTrigger>
                  <SelectContent>
                    <SelectItem value="unassigned">Unassigned</SelectItem>
                    {activeTeachers.map((teacher) => (
                      <SelectItem key={teacher.id} value={teacher.id}>
                        {teacher.firstName} {teacher.lastName}
                      </SelectItem>
                    ))}
                  </SelectContent>
                </Select>
              </div>
              <div className="flex justify-end space-x-2">
                <Button variant="outline" onClick={() => setIsEditDialogOpen(false)}>
                  Cancel
                </Button>
                <Button onClick={handleEditClass}>
                  Update Class
                </Button>
              </div>
            </div>
          </DialogContent>
        </Dialog>
      </div>
    </DashboardLayout>
  );
}